@@ -1,6 +1,6 @@
 # _*_ coding: utf-8 _*_
 #
-# hspylib-firebase v0.9.60
+# hspylib-firebase v0.9.61
 #
 # Package: main.firebase.core
 """Package initialization."""
@@ -8,6 +8,7 @@
 __all__ = [
   'agent_config', 
   'file_processor', 
-  'firebase'
+  'firebase', 
+  'firebase_auth'
 ]
-__version__ = '0.9.60'
+__version__ = '0.9.61'
